Skip site navigation (1)Skip section navigation (2)

  
 
  

home | help
lxi(1)				  User Commands 			  lxi(1)

NAME
     lxi - a tool for managing LXI compatible instruments.

SYNOPSIS
     lxi [--help] [--version] <command> [<args>]

DESCRIPTION
     lxi  is  a commandline tool for controlling LXI compatible instruments such
     as modern oscilloscopes, power supplies, spectrum analyzers, etc.

OPTIONS
     -h, --help
	    Display help

     -v, --version
	    Display program version

COMMANDS
     discover [<options>]
	    Search available networks for LXI devices

     scpi [<options>] <scpi-command>
	    Send SCPI command

     screenshot [<options>] [<filename>]
	    Capture screenshot

     benchmark [<options>]
	    Benchmark

     run <filename>
	    Run Lua script

DISCOVER OPTIONS
     -t, --timeout <seconds>
	    Timeout in seconds

     -m, --mdns
	    Search via mDNS/DNS-SD

SCPI OPTIONS
     -a, --address <ip>
	    IP address of LXI device

     -p, --port
	    Use port

     -t, --timeout <seconds>
	    Timeout in seconds

     -x, --hex
	    Print response in hexadecimal

     -i, --interactive
	    Enter interactive mode

     -r, --raw
	    Use raw/TCP protocol

SCREENSHOT OPTIONS
     -a, --address <ip>
	    IP address of LXI device

     -t, --timeout <seconds>
	    Timeout in seconds

     -p, --plugin <name>
	    Use screenshot plugin by name

	    If this option is omitted the tool will automatically try to  select
	    the most suitable plugin.

     -l, --list
	    List available screenshot plugins

     To write screenshot image to stdout simply use '-' as the output filename.

BENCHMARK OPTIONS
     -a, --address <ip>
	    IP address of LXI device

     -p, --port
	    Use port

     -t, --timeout <seconds>
	    Timeout in seconds

     -c, --count <count>
	    Number of request messages

     -r, --raw
	    Use raw/TCP protocol

EXAMPLES
     Search for LXI instruments:

	    lxi discover

     Search for LXI instruments using mDNS/DNS-SD:

	    lxi discover --mdns

     Send SCPI command:

	    lxi scpi --address 10.0.0.42 "*IDN?"

     Send SCPI command and dump response to file:

	    lxi scpi --address 10.0.0.42 "*IDN?" > response.txt

     Capture screenshot from a Rigol 1000Z series oscilloscope:

	    lxi screenshot --address 10.0.0.42 --plugin rigol-1000z

	    Or by using screenshot plugin autodetection simply:

	    lxi screenshot --address 10.0.0.42

     Note: Some LXI devices are slow to process SCPI commands, in which case you
     might need to take care to increase the timeout value.

WEBSITE
     Visit https://lxi-tools.github.io

AUTHOR
     Written by Martin Lund <martin.lund@keep-it-simple.com>

lxi-tools			   2024-11-30				  lxi(1)

Want to link to this manual page? Use this URL:
<https://man.freebsd.org/cgi/man.cgi?query=lxi&sektion=1&manpath=FreeBSD+Ports+15.1.quarterly>

home | help